==> xlniuxdata-vipgame-1.0.1-20150205.061102-31-sources.jar: com/xunlei/niux/data/vipgame/dto/MobileGameDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * 手游信息
 * @author lisu 
 * 2014-08-12
 */
public class MobileGameDTO {
	
	private String gameId;
	private String gameNo;
	private String gameName;	
	private String featureId;
	private String typeId;
	private String icon;
	private String gameOfficialLink;
	private String downloadLink;
	private String downloadNum;


	public String getIcon() {
		return icon;
	}
	public void setIcon(String icon) {
		this.icon = icon;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getGameNo() {
		return gameNo;
	}
	public void setGameNo(String gameNo) {
		this.gameNo = gameNo;
	}
	public String getGameName() {
		return gameName;
	}
	public void setGameName(String gameName) {
		this.gameName = gameName;
	}
	public String getGameOfficialLink() {
		return gameOfficialLink;
	}
	public void setGameOfficialLink(String gameOfficialLink) {
		this.gameOfficialLink = gameOfficialLink;
	}
	public String getDownloadLink() {
		return downloadLink;
	}
	public void setDownloadLink(String downloadLink) {
		this.downloadLink = downloadLink;
	}
	public String getDownloadNum() {
		return downloadNum;
	}
	public void setDownloadNum(String downloadNum) {
		this.downloadNum = downloadNum;
	}
	public String getTypeId() {
		return typeId;
	}
	public void setTypeId(String typeId) {
		this.typeId = typeId;
	}
	public String getFeatureId() {
		return featureId;
	}
	public void setFeatureId(String featureId) {
		this.featureId = featureId;
	}

	
}

==> xlniuxdata-vipgame-1.0.62-sources.jar: com/xunlei/niux/data/vipgame/dto/MobileGameDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * 手游信息
 * @author lisu 
 * 2014-08-12
 */
public class MobileGameDTO {
	
	private String gameId;
	private String gameNo;
	private String gameName;	
	private String featureId;
	private String typeId;
	private String icon;
	private String gameOfficialLink;
	private String downloadLink;
	private String downloadNum;
    private Integer displayOrder;


	public String getIcon() {
		return icon;
	}
	public void setIcon(String icon) {
		this.icon = icon;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getGameNo() {
		return gameNo;
	}
	public void setGameNo(String gameNo) {
		this.gameNo = gameNo;
	}
	public String getGameName() {
		return gameName;
	}
	public void setGameName(String gameName) {
		this.gameName = gameName;
	}
	public String getGameOfficialLink() {
		return gameOfficialLink;
	}
	public void setGameOfficialLink(String gameOfficialLink) {
		this.gameOfficialLink = gameOfficialLink;
	}
	public String getDownloadLink() {
		return downloadLink;
	}
	public void setDownloadLink(String downloadLink) {
		this.downloadLink = downloadLink;
	}
	public String getDownloadNum() {
		return downloadNum;
	}
	public void setDownloadNum(String downloadNum) {
		this.downloadNum = downloadNum;
	}
	public String getTypeId() {
		return typeId;
	}
	public void setTypeId(String typeId) {
		this.typeId = typeId;
	}
	public String getFeatureId() {
		return featureId;
	}
	public void setFeatureId(String featureId) {
		this.featureId = featureId;
	}

    public Integer getDisplayOrder() {
        return displayOrder;
    }

    public void setDisplayOrder(Integer displayOrder) {
        this.displayOrder = displayOrder;
    }
}
